@@ -5,17 +5,22 @@ import logging
 from pyatome.client import AtomeClient, PyAtomeError
 import voluptuous as vol
 
-from homeassistant.components.sensor import PLATFORM_SCHEMA, SensorEntity
+from homeassistant.components.sensor import (
+    PLATFORM_SCHEMA,
+    STATE_CLASS_MEASUREMENT,
+    SensorEntity,
+)
 from homeassistant.const import (
     CONF_NAME,
     CONF_PASSWORD,
     CONF_USERNAME,
+    DEVICE_CLASS_ENERGY,
     DEVICE_CLASS_POWER,
     ENERGY_KILO_WATT_HOUR,
     POWER_WATT,
 )
 import homeassistant.helpers.config_validation as cv
-from homeassistant.util import Throttle
+from homeassistant.util import Throttle, dt as dt_util
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -39,8 +44,6 @@ WEEKLY_TYPE = "week"
 MONTHLY_TYPE = "month"
 YEARLY_TYPE = "year"
 
-ICON = "mdi:flash"
-
 PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
     {
         vol.Required(CONF_USERNAME): cv.string,
@@ -77,7 +80,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
 class AtomeData:
     """Stores data retrieved from Neurio sensor."""
 
-    def __init__(self, client: AtomeClient):
+    def __init__(self, client: AtomeClient) -> None:
         """Initialize the data."""
         self.atome_client = client
         self._live_power = None
@@ -85,12 +88,16 @@ class AtomeData:
         self._is_connected = None
         self._day_usage = None
         self._day_price = None
+        self._day_last_reset = None
         self._week_usage = None
         self._week_price = None
+        self._week_last_reset = None
         self._month_usage = None
         self._month_price = None
+        self._month_last_reset = None
         self._year_usage = None
         self._year_price = None
+        self._year_last_reset = None
 
     @property
     def live_power(self):
@@ -135,6 +142,11 @@ class AtomeData:
         """Return latest daily usage value."""
         return self._day_price
 
+    @property
+    def day_last_reset(self):
+        """Return latest daily last reset."""
+        return self._day_last_reset
+
     @Throttle(DAILY_SCAN_INTERVAL)
     def update_day_usage(self):
         """Return current daily power usage."""
@@ -142,6 +154,7 @@ class AtomeData:
             values = self.atome_client.get_consumption(DAILY_TYPE)
             self._day_usage = values["total"] / 1000
             self._day_price = values["price"]
+            self._day_last_reset = dt_util.parse_datetime(values["startPeriod"])
             _LOGGER.debug("Updating Atome daily data. Got: %d", self._day_usage)
 
         except KeyError as error:
@@ -157,6 +170,11 @@ class AtomeData:
         """Return latest weekly usage value."""
         return self._week_price
 
+    @property
+    def week_last_reset(self):
+        """Return latest weekly last reset value."""
+        return self._week_last_reset
+
     @Throttle(WEEKLY_SCAN_INTERVAL)
     def update_week_usage(self):
         """Return current weekly power usage."""
@@ -164,6 +182,7 @@ class AtomeData:
             values = self.atome_client.get_consumption(WEEKLY_TYPE)
             self._week_usage = values["total"] / 1000
             self._week_price = values["price"]
+            self._week_last_reset = dt_util.parse_datetime(values["startPeriod"])
             _LOGGER.debug("Updating Atome weekly data. Got: %d", self._week_usage)
 
         except KeyError as error:
@@ -179,6 +198,11 @@ class AtomeData:
         """Return latest monthly usage value."""
         return self._month_price
 
+    @property
+    def month_last_reset(self):
+        """Return latest monthly last reset value."""
+        return self._month_last_reset
+
     @Throttle(MONTHLY_SCAN_INTERVAL)
     def update_month_usage(self):
         """Return current monthly power usage."""
@@ -186,6 +210,7 @@ class AtomeData:
             values = self.atome_client.get_consumption(MONTHLY_TYPE)
             self._month_usage = values["total"] / 1000
             self._month_price = values["price"]
+            self._month_last_reset = dt_util.parse_datetime(values["startPeriod"])
             _LOGGER.debug("Updating Atome monthly data. Got: %d", self._month_usage)
 
         except KeyError as error:
@@ -201,6 +226,11 @@ class AtomeData:
         """Return latest yearly usage value."""
         return self._year_price
 
+    @property
+    def year_last_reset(self):
+        """Return latest yearly last reset value."""
+        return self._year_last_reset
+
     @Throttle(YEARLY_SCAN_INTERVAL)
     def update_year_usage(self):
         """Return current yearly power usage."""
@@ -208,6 +238,7 @@ class AtomeData:
             values = self.atome_client.get_consumption(YEARLY_TYPE)
             self._year_usage = values["total"] / 1000
             self._year_price = values["price"]
+            self._year_last_reset = dt_util.parse_datetime(values["startPeriod"])
             _LOGGER.debug("Updating Atome yearly data. Got: %d", self._year_usage)
 
         except KeyError as error:
@@ -219,47 +250,18 @@ class AtomeSensor(SensorEntity):
 
     def __init__(self, data, name, sensor_type):
         """Initialize the sensor."""
-        self._name = name
+        self._attr_name = name
         self._data = data
-        self._state = None
-        self._attributes = {}
 
         self._sensor_type = sensor_type
+        self._attr_state_class = STATE_CLASS_MEASUREMENT
 
         if sensor_type == LIVE_TYPE:
-            self._unit_of_measurement = POWER_WATT
+            self._attr_device_class = DEVICE_CLASS_POWER
+            self._attr_unit_of_measurement = POWER_WATT
         else:
-            self._unit_of_measurement = ENERGY_KILO_WATT_HOUR
-
-    @property
-    def name(self):
-        """Return the name of the sensor."""
-        return self._name
-
-    @property
-    def state(self):
-        """Return the state of the sensor."""
-        return self._state
-
-    @property
-    def extra_state_attributes(self):
-        """Return the state attributes."""
-        return self._attributes
-
-    @property
-    def unit_of_measurement(self):
-        """Return the unit of measurement."""
-        return self._unit_of_measurement
-
-    @property
-    def icon(self):
-        """Icon to use in the frontend, if any."""
-        return ICON
-
-    @property
-    def device_class(self):
-        """Return the device class."""
-        return DEVICE_CLASS_POWER
+            self._attr_device_class = DEVICE_CLASS_ENERGY
+            self._attr_unit_of_measurement = ENERGY_KILO_WATT_HOUR
 
     def update(self):
         """Update device state."""
@@ -267,11 +269,16 @@ class AtomeSensor(SensorEntity):
         update_function()
 
         if self._sensor_type == LIVE_TYPE:
-            self._state = self._data.live_power
-            self._attributes["subscribed_power"] = self._data.subscribed_power
-            self._attributes["is_connected"] = self._data.is_connected
+            self._attr_state = self._data.live_power
+            self._attr_extra_state_attributes = {
+                "subscribed_power": self._data.subscribed_power,
+                "is_connected": self._data.is_connected,
+            }
         else:
-            self._state = getattr(self._data, f"{self._sensor_type}_usage")
-            self._attributes["price"] = getattr(
-                self._data, f"{self._sensor_type}_price"
+            self._attr_state = getattr(self._data, f"{self._sensor_type}_usage")
+            self._attr_last_reset = dt_util.as_utc(
+                getattr(self._data, f"{self._sensor_type}_last_reset")
             )
+            self._attr_extra_state_attributes = {
+                "price": getattr(self._data, f"{self._sensor_type}_price")
+            }
