@@ -17,11 +17,14 @@ from homeassistant.const import (
     CONF_TIMEOUT,
     CONF_TOKEN,
 )
+from homeassistant.helpers.device_registry import format_mac
 
 from .const import (
     CONF_DESCRIPTION,
+    LEGACY_PORT,
     LOGGER,
     METHOD_LEGACY,
+    METHOD_WEBSOCKET,
     RESULT_AUTH_MISSING,
     RESULT_CANNOT_CONNECT,
     RESULT_NOT_SUPPORTED,
@@ -34,13 +37,44 @@ from .const import (
 )
 
 
+def mac_from_device_info(info):
+    """Extract the mac address from the device info."""
+    dev_info = info.get("device", {})
+    if dev_info.get("networkType") == "wireless" and dev_info.get("wifiMac"):
+        return format_mac(dev_info["wifiMac"])
+    return None
+
+
+async def async_get_device_info(hass, bridge, host):
+    """Fetch the port, method, and device info."""
+    return await hass.async_add_executor_job(_get_device_info, bridge, host)
+
+
+def _get_device_info(bridge, host):
+    """Fetch the port, method, and device info."""
+    if bridge and bridge.port:
+        return bridge.port, bridge.method, bridge.device_info()
+
+    for port in WEBSOCKET_PORTS:
+        bridge = SamsungTVBridge.get_bridge(METHOD_WEBSOCKET, host, port)
+        if info := bridge.device_info():
+            return port, METHOD_WEBSOCKET, info
+
+    bridge = SamsungTVBridge.get_bridge(METHOD_LEGACY, host, LEGACY_PORT)
+    result = bridge.try_connect()
+    if result in (RESULT_SUCCESS, RESULT_AUTH_MISSING):
+        return LEGACY_PORT, METHOD_LEGACY, None
+
+    return None, None, None
+
+
 class SamsungTVBridge(ABC):
     """The Base Bridge abstract class."""
 
     @staticmethod
     def get_bridge(method, host, port=None, token=None):
         """Get Bridge instance."""
-        if method == METHOD_LEGACY:
+        if method == METHOD_LEGACY or port == LEGACY_PORT:
             return SamsungTVLegacyBridge(method, host, port)
         return SamsungTVWSBridge(method, host, port, token)
 
@@ -50,7 +84,6 @@ class SamsungTVBridge(ABC):
         self.method = method
         self.host = host
         self.token = None
-        self.default_port = None
         self._remote = None
         self._callback = None
 
@@ -66,6 +99,10 @@ class SamsungTVBridge(ABC):
     def device_info(self):
         """Try to gather infos of this TV."""
 
+    @abstractmethod
+    def mac_from_device(self):
+        """Try to fetch the mac address of the TV."""
+
     def is_on(self):
         """Tells if the TV is on."""
         if self._remote:
@@ -137,7 +174,7 @@ class SamsungTVLegacyBridge(SamsungTVBridge):
 
     def __init__(self, method, host, port):
         """Initialize Bridge."""
-        super().__init__(method, host, None)
+        super().__init__(method, host, LEGACY_PORT)
         self.config = {
             CONF_NAME: VALUE_CONF_NAME,
             CONF_DESCRIPTION: VALUE_CONF_NAME,
@@ -148,6 +185,10 @@ class SamsungTVLegacyBridge(SamsungTVBridge):
             CONF_TIMEOUT: 1,
         }
 
+    def mac_from_device(self):
+        """Try to fetch the mac address of the TV."""
+        return None
+
     def try_connect(self):
         """Try to connect to the Legacy TV."""
         config = {
@@ -168,8 +209,8 @@ class SamsungTVLegacyBridge(SamsungTVBridge):
         except AccessDenied:
             LOGGER.debug("Working but denied config: %s", config)
             return RESULT_AUTH_MISSING
-        except UnhandledResponse:
-            LOGGER.debug("Working but unsupported config: %s", config)
+        except UnhandledResponse as err:
+            LOGGER.debug("Working but unsupported config: %s, error: %s", config, err)
             return RESULT_NOT_SUPPORTED
         except (ConnectionClosed, OSError) as err:
             LOGGER.debug("Failing config: %s, error: %s", config, err)
@@ -193,6 +234,8 @@ class SamsungTVLegacyBridge(SamsungTVBridge):
             except AccessDenied:
                 self._notify_callback()
                 raise
+            except (ConnectionClosed, OSError):
+                pass
         return self._remote
 
     def _send_key(self, key):
@@ -212,7 +255,11 @@ class SamsungTVWSBridge(SamsungTVBridge):
         """Initialize Bridge."""
         super().__init__(method, host, port)
         self.token = token
-        self.default_port = 8001
+
+    def mac_from_device(self):
+        """Try to fetch the mac address of the TV."""
+        info = self.device_info()
+        return mac_from_device_info(info) if info else None
 
     def try_connect(self):
         """Try to connect to the Websocket TV."""
@@ -242,8 +289,10 @@ class SamsungTVWSBridge(SamsungTVBridge):
                         config[CONF_TOKEN] = "*****"
                 LOGGER.debug("Working config: %s", config)
                 return RESULT_SUCCESS
-            except WebSocketException:
-                LOGGER.debug("Working but unsupported config: %s", config)
+            except WebSocketException as err:
+                LOGGER.debug(
+                    "Working but unsupported config: %s, error: %s", config, err
+                )
                 result = RESULT_NOT_SUPPORTED
             except (OSError, ConnectionFailure) as err:
                 LOGGER.debug("Failing config: %s, error: %s", config, err)
